@@ -136,7 +136,7 @@ typedef struct _GstBufferClass GstBufferClass;
  * GST_BUFFER_MALLOCDATA:
  * @buf: a #GstBuffer.
  *
- * A pointer to any data allocated for this buffer using malloc(). If this is 
+ * A pointer to any data allocated for this buffer using g_malloc(). If this is 
  * non-NULL, this memory will be freed at the end of the buffer's lifecycle 
  * (i.e. when its refcount becomes zero).
  */
@@ -198,7 +198,8 @@ typedef struct _GstBufferClass GstBufferClass;
  * network source.
  * @GST_BUFFER_FLAG_IN_CAPS: the buffer has been added as a field in a #GstCaps.
  * @GST_BUFFER_FLAG_GAP: the buffer has been created to fill a gap in the
- * stream.
+ * stream and contains media neutral data (elements can switch to optimized code
+ * path that ignores the buffer content).
  * @GST_BUFFER_FLAG_DELTA_UNIT: this unit cannot be decoded independently.
  * @GST_BUFFER_FLAG_LAST: additional flags can be added starting from this flag.
  *
@@ -233,7 +234,7 @@ typedef enum {
  * @offset_end: the last offset contained in this buffer. It has the same 
  *     format as @offset.
  * @malloc_data: a pointer to the allocated memory associated with this buffer.
- *     When the buffer is freed, this data will freed with free().
+ *     When the buffer is freed, this data will freed with g_free().
  *
  * The structure of a #GstBuffer. Use the associated macros to access the public
  * variables.
@@ -267,10 +268,12 @@ struct _GstBufferClass {
   GstMiniObjectClass    mini_object_class;
 };
 
+GType       gst_buffer_get_type (void);
+
 /* allocation */
-GType		gst_buffer_get_type		(void);
-GstBuffer*	gst_buffer_new			(void);
-GstBuffer*	gst_buffer_new_and_alloc	(guint size);
+GstBuffer * gst_buffer_new               (void);
+GstBuffer * gst_buffer_new_and_alloc     (guint size);
+GstBuffer * gst_buffer_try_new_and_alloc (guint size);
 
 /**
  * gst_buffer_set_data:
@@ -338,6 +341,39 @@ gst_buffer_ref (GstBuffer * buf)
  * copy of the data the source buffer contains.
  */
 #define		gst_buffer_copy(buf)		GST_BUFFER_CAST (gst_mini_object_copy (GST_MINI_OBJECT_CAST (buf)))
+
+/**
+ * GstBufferCopyFlags:
+ * @GST_BUFFER_COPY_FLAGS: flag indicating that buffer flags should be copied
+ * @GST_BUFFER_COPY_TIMESTAMPS: flag indicating that buffer timestamp, duration,
+ * offset and offset_end should be copied
+ * @GST_BUFFER_COPY_CAPS: flag indicating that buffer caps should be copied
+ *
+ * A set of flags that can be provided to the gst_buffer_copy_metadata()
+ * function to specify which metadata fields should be copied.
+ *
+ * Since: 0.10.13
+ */
+typedef enum {
+  GST_BUFFER_COPY_FLAGS      = (1 << 0),
+  GST_BUFFER_COPY_TIMESTAMPS = (1 << 1),
+  GST_BUFFER_COPY_CAPS       = (1 << 2)
+} GstBufferCopyFlags;
+
+/**
+ * GST_BUFFER_COPY_ALL:
+ *
+ * Combination of all possible fields that can be copied with
+ * gst_buffer_copy_metadata().
+ *
+ * Since: 0.10.13
+ */
+#define GST_BUFFER_COPY_ALL (GST_BUFFER_COPY_FLAGS | GST_BUFFER_COPY_TIMESTAMPS | GST_BUFFER_COPY_CAPS)
+
+/* copies metadata into newly allocated buffer */
+void            gst_buffer_copy_metadata        (GstBuffer *dest, const GstBuffer *src,
+                                                 GstBufferCopyFlags flags);
+
 /**
  * gst_buffer_is_writable:
  * @buf: a #GstBuffer
@@ -376,7 +412,12 @@ GstBuffer*      gst_buffer_make_metadata_writable (GstBuffer *buf);
  *
  * Either @nbuf or the #GstBuffer pointed to by @obuf may be NULL.
  */
-#define		gst_buffer_replace(obuf,nbuf)	gst_mini_object_replace ((GstMiniObject **)(obuf), GST_MINI_OBJECT_CAST (nbuf))
+#define		gst_buffer_replace(obuf,nbuf) \
+G_STMT_START {						                      \
+  GstBuffer **___obufaddr = (GstBuffer **)(obuf);         \
+  gst_mini_object_replace ((GstMiniObject **)___obufaddr, \
+      GST_MINI_OBJECT_CAST (nbuf));                       \
+} G_STMT_END
 
 GstCaps*	gst_buffer_get_caps		(GstBuffer *buffer);
 void		gst_buffer_set_caps		(GstBuffer *buffer, GstCaps *caps);
@@ -414,9 +455,6 @@ GstBuffer*	gst_buffer_span			(GstBuffer *buf1, guint32 offset, GstBuffer *buf2,
  */
 #define		gst_value_get_buffer(v)		GST_BUFFER_CAST (gst_value_get_mini_object(v))
 
-/* --- protected --- */
-void		_gst_buffer_initialize		(void);
-
 G_END_DECLS
 
 #endif /* __GST_BUFFER_H__ */
